utilities

package
v0.0.55 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 12, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package utilities provides shared configuration-loading helpers for the config module.

Its main responsibility is to load application settings from application.yml or application.json, merge .env and .env.local files, and apply environment-variable overrides derived from the Viper key paths.

Main entry point:

  • LoadEnv to load configuration files and apply override rules

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func LoadEnv

func LoadEnv(prefixPath string) error

Types

This section is empty.

Directories

Path Synopsis
Package traces configures OpenTelemetry tracing and metrics for the config module.
Package traces configures OpenTelemetry tracing and metrics for the config module.

Jump to