common

package
v0.0.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CurveAsymmetricKey

type CurveAsymmetricKey string

CurveAsymmetricKey defines the supported elliptic curves for ECC encryption.

const (
	// CurveP256 represents the NIST P-256 curve.
	CurveP256 CurveAsymmetricKey = "P-256"
	// CurveP384 represents the NIST P-384 curve.
	CurveP384 CurveAsymmetricKey = "P-384"
	// CurveP521 represents the NIST P-521 curve.
	CurveP521 CurveAsymmetricKey = "P-521"
)

type SizeAsymetrycKey

type SizeAsymetrycKey uint

SizeAsymetrycKey defines the supported asymmetric key sizes in bits.

const (
	// Key2048Bits represents a 2048-bit asymmetric key.
	Key2048Bits SizeAsymetrycKey = 2048
	// Key3072Bits represents a 3072-bit asymmetric key.
	Key3072Bits SizeAsymetrycKey = 3072
	// Key4096Bits represents a 4096-bit asymmetric key.
	Key4096Bits SizeAsymetrycKey = 4096
)

type SizeSymetrycKey

type SizeSymetrycKey uint

SizeSymetrycKey defines the supported symmetric key sizes in bytes.

const (
	// Key128Bits represents a 128-bit symmetric key.
	Key128Bits SizeSymetrycKey = 16
	// Key256Bits represents a 256-bit symmetric key.
	Key256Bits SizeSymetrycKey = 32
)

Jump to