Documentation
¶
Index ¶
- Constants
- Variables
- func RegisterGreeterServer(s grpc.ServiceRegistrar, srv GreeterServer)
- type AlertMessage
- func (*AlertMessage) Descriptor() ([]byte, []int)deprecated
- func (x *AlertMessage) GetAlertId() string
- func (x *AlertMessage) GetCreatedAtUnix() int64
- func (x *AlertMessage) GetLevel() string
- func (x *AlertMessage) GetMessage() string
- func (x *AlertMessage) GetSource() string
- func (*AlertMessage) ProtoMessage()
- func (x *AlertMessage) ProtoReflect() protoreflect.Message
- func (x *AlertMessage) Reset()
- func (x *AlertMessage) String() string
- type ChatMessage
- func (*ChatMessage) Descriptor() ([]byte, []int)deprecated
- func (x *ChatMessage) GetMessage() string
- func (x *ChatMessage) GetSentAtUnix() int64
- func (x *ChatMessage) GetUser() string
- func (*ChatMessage) ProtoMessage()
- func (x *ChatMessage) ProtoReflect() protoreflect.Message
- func (x *ChatMessage) Reset()
- func (x *ChatMessage) String() string
- type ChatSummary
- func (*ChatSummary) Descriptor() ([]byte, []int)deprecated
- func (x *ChatSummary) GetChatId() string
- func (x *ChatSummary) GetLastMessage() string
- func (x *ChatSummary) GetTotalMessages() int32
- func (*ChatSummary) ProtoMessage()
- func (x *ChatSummary) ProtoReflect() protoreflect.Message
- func (x *ChatSummary) Reset()
- func (x *ChatSummary) String() string
- type GreeterClient
- type GreeterServer
- type Greeter_CreateChatClient
- type Greeter_CreateChatServer
- type Greeter_StreamAlertsClient
- type Greeter_StreamAlertsServer
- type HelloReply
- type HelloRequest
- type UnimplementedGreeterServer
- func (UnimplementedGreeterServer) CreateChat(grpc.ClientStreamingServer[ChatMessage, ChatSummary]) error
- func (UnimplementedGreeterServer) SayHello(context.Context, *HelloRequest) (*HelloReply, error)
- func (UnimplementedGreeterServer) StreamAlerts(grpc.BidiStreamingServer[AlertMessage, AlertMessage]) error
- type UnsafeGreeterServer
Constants ¶
const ( Greeter_SayHello_FullMethodName = "/helloworld.Greeter/SayHello" Greeter_CreateChat_FullMethodName = "/helloworld.Greeter/CreateChat" Greeter_StreamAlerts_FullMethodName = "/helloworld.Greeter/StreamAlerts" )
Variables ¶
var File_proto_methods_proto protoreflect.FileDescriptor
var Greeter_ServiceDesc = grpc.ServiceDesc{ ServiceName: "helloworld.Greeter", HandlerType: (*GreeterServer)(nil), Methods: []grpc.MethodDesc{ { MethodName: "SayHello", Handler: _Greeter_SayHello_Handler, }, }, Streams: []grpc.StreamDesc{ { StreamName: "CreateChat", Handler: _Greeter_CreateChat_Handler, ClientStreams: true, }, { StreamName: "StreamAlerts", Handler: _Greeter_StreamAlerts_Handler, ServerStreams: true, ClientStreams: true, }, }, Metadata: "proto/methods.proto", }
Greeter_ServiceDesc is the grpc.ServiceDesc for Greeter service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)
Functions ¶
func RegisterGreeterServer ¶
func RegisterGreeterServer(s grpc.ServiceRegistrar, srv GreeterServer)
Types ¶
type AlertMessage ¶
type AlertMessage struct {
AlertId string `protobuf:"bytes,1,opt,name=alert_id,json=alertId,proto3" json:"alert_id,omitempty"`
Source string `protobuf:"bytes,2,opt,name=source,proto3" json:"source,omitempty"`
Level string `protobuf:"bytes,3,opt,name=level,proto3" json:"level,omitempty"`
Message string `protobuf:"bytes,4,opt,name=message,proto3" json:"message,omitempty"`
CreatedAtUnix int64 `protobuf:"varint,5,opt,name=created_at_unix,json=createdAtUnix,proto3" json:"created_at_unix,omitempty"`
// contains filtered or unexported fields
}
Alert event used in bidirectional streaming tests.
func (*AlertMessage) Descriptor
deprecated
func (*AlertMessage) Descriptor() ([]byte, []int)
Deprecated: Use AlertMessage.ProtoReflect.Descriptor instead.
func (*AlertMessage) GetAlertId ¶
func (x *AlertMessage) GetAlertId() string
func (*AlertMessage) GetCreatedAtUnix ¶
func (x *AlertMessage) GetCreatedAtUnix() int64
func (*AlertMessage) GetLevel ¶
func (x *AlertMessage) GetLevel() string
func (*AlertMessage) GetMessage ¶
func (x *AlertMessage) GetMessage() string
func (*AlertMessage) GetSource ¶
func (x *AlertMessage) GetSource() string
func (*AlertMessage) ProtoMessage ¶
func (*AlertMessage) ProtoMessage()
func (*AlertMessage) ProtoReflect ¶
func (x *AlertMessage) ProtoReflect() protoreflect.Message
func (*AlertMessage) Reset ¶
func (x *AlertMessage) Reset()
func (*AlertMessage) String ¶
func (x *AlertMessage) String() string
type ChatMessage ¶
type ChatMessage struct {
User string `protobuf:"bytes,1,opt,name=user,proto3" json:"user,omitempty"`
Message string `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
SentAtUnix int64 `protobuf:"varint,3,opt,name=sent_at_unix,json=sentAtUnix,proto3" json:"sent_at_unix,omitempty"`
// contains filtered or unexported fields
}
A single chat message sent by the client during a chat session.
func (*ChatMessage) Descriptor
deprecated
func (*ChatMessage) Descriptor() ([]byte, []int)
Deprecated: Use ChatMessage.ProtoReflect.Descriptor instead.
func (*ChatMessage) GetMessage ¶
func (x *ChatMessage) GetMessage() string
func (*ChatMessage) GetSentAtUnix ¶
func (x *ChatMessage) GetSentAtUnix() int64
func (*ChatMessage) GetUser ¶
func (x *ChatMessage) GetUser() string
func (*ChatMessage) ProtoMessage ¶
func (*ChatMessage) ProtoMessage()
func (*ChatMessage) ProtoReflect ¶
func (x *ChatMessage) ProtoReflect() protoreflect.Message
func (*ChatMessage) Reset ¶
func (x *ChatMessage) Reset()
func (*ChatMessage) String ¶
func (x *ChatMessage) String() string
type ChatSummary ¶
type ChatSummary struct {
ChatId string `protobuf:"bytes,1,opt,name=chat_id,json=chatId,proto3" json:"chat_id,omitempty"`
TotalMessages int32 `protobuf:"varint,2,opt,name=total_messages,json=totalMessages,proto3" json:"total_messages,omitempty"`
LastMessage string `protobuf:"bytes,3,opt,name=last_message,json=lastMessage,proto3" json:"last_message,omitempty"`
// contains filtered or unexported fields
}
Summary returned when a client-streaming chat session ends.
func (*ChatSummary) Descriptor
deprecated
func (*ChatSummary) Descriptor() ([]byte, []int)
Deprecated: Use ChatSummary.ProtoReflect.Descriptor instead.
func (*ChatSummary) GetChatId ¶
func (x *ChatSummary) GetChatId() string
func (*ChatSummary) GetLastMessage ¶
func (x *ChatSummary) GetLastMessage() string
func (*ChatSummary) GetTotalMessages ¶
func (x *ChatSummary) GetTotalMessages() int32
func (*ChatSummary) ProtoMessage ¶
func (*ChatSummary) ProtoMessage()
func (*ChatSummary) ProtoReflect ¶
func (x *ChatSummary) ProtoReflect() protoreflect.Message
func (*ChatSummary) Reset ¶
func (x *ChatSummary) Reset()
func (*ChatSummary) String ¶
func (x *ChatSummary) String() string
type GreeterClient ¶
type GreeterClient interface {
// Sends a greeting
SayHello(ctx context.Context, in *HelloRequest, opts ...grpc.CallOption) (*HelloReply, error)
// Receives a sequence of chat messages and returns a summary when the client finishes sending.
CreateChat(ctx context.Context, opts ...grpc.CallOption) (grpc.ClientStreamingClient[ChatMessage, ChatSummary], error)
// Exchanges alert messages in both directions in real time.
StreamAlerts(ctx context.Context, opts ...grpc.CallOption) (grpc.BidiStreamingClient[AlertMessage, AlertMessage], error)
}
GreeterClient is the client API for Greeter service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.
The greeting service definition.
func NewGreeterClient ¶
func NewGreeterClient(cc grpc.ClientConnInterface) GreeterClient
type GreeterServer ¶
type GreeterServer interface {
// Sends a greeting
SayHello(context.Context, *HelloRequest) (*HelloReply, error)
// Receives a sequence of chat messages and returns a summary when the client finishes sending.
CreateChat(grpc.ClientStreamingServer[ChatMessage, ChatSummary]) error
// Exchanges alert messages in both directions in real time.
StreamAlerts(grpc.BidiStreamingServer[AlertMessage, AlertMessage]) error
// contains filtered or unexported methods
}
GreeterServer is the server API for Greeter service. All implementations must embed UnimplementedGreeterServer for forward compatibility.
The greeting service definition.
type Greeter_CreateChatClient ¶
type Greeter_CreateChatClient = grpc.ClientStreamingClient[ChatMessage, ChatSummary]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Greeter_CreateChatServer ¶
type Greeter_CreateChatServer = grpc.ClientStreamingServer[ChatMessage, ChatSummary]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Greeter_StreamAlertsClient ¶
type Greeter_StreamAlertsClient = grpc.BidiStreamingClient[AlertMessage, AlertMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type Greeter_StreamAlertsServer ¶
type Greeter_StreamAlertsServer = grpc.BidiStreamingServer[AlertMessage, AlertMessage]
This type alias is provided for backwards compatibility with existing code that references the prior non-generic stream type by name.
type HelloReply ¶
type HelloReply struct {
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
// contains filtered or unexported fields
}
The response message containing the greetings
func (*HelloReply) Descriptor
deprecated
func (*HelloReply) Descriptor() ([]byte, []int)
Deprecated: Use HelloReply.ProtoReflect.Descriptor instead.
func (*HelloReply) GetMessage ¶
func (x *HelloReply) GetMessage() string
func (*HelloReply) ProtoMessage ¶
func (*HelloReply) ProtoMessage()
func (*HelloReply) ProtoReflect ¶
func (x *HelloReply) ProtoReflect() protoreflect.Message
func (*HelloReply) Reset ¶
func (x *HelloReply) Reset()
func (*HelloReply) String ¶
func (x *HelloReply) String() string
type HelloRequest ¶
type HelloRequest struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
// contains filtered or unexported fields
}
The request message containing the user's name.
func (*HelloRequest) Descriptor
deprecated
func (*HelloRequest) Descriptor() ([]byte, []int)
Deprecated: Use HelloRequest.ProtoReflect.Descriptor instead.
func (*HelloRequest) GetName ¶
func (x *HelloRequest) GetName() string
func (*HelloRequest) ProtoMessage ¶
func (*HelloRequest) ProtoMessage()
func (*HelloRequest) ProtoReflect ¶
func (x *HelloRequest) ProtoReflect() protoreflect.Message
func (*HelloRequest) Reset ¶
func (x *HelloRequest) Reset()
func (*HelloRequest) String ¶
func (x *HelloRequest) String() string
type UnimplementedGreeterServer ¶
type UnimplementedGreeterServer struct{}
UnimplementedGreeterServer must be embedded to have forward compatible implementations.
NOTE: this should be embedded by value instead of pointer to avoid a nil pointer dereference when methods are called.
func (UnimplementedGreeterServer) CreateChat ¶
func (UnimplementedGreeterServer) CreateChat(grpc.ClientStreamingServer[ChatMessage, ChatSummary]) error
func (UnimplementedGreeterServer) SayHello ¶
func (UnimplementedGreeterServer) SayHello(context.Context, *HelloRequest) (*HelloReply, error)
func (UnimplementedGreeterServer) StreamAlerts ¶
func (UnimplementedGreeterServer) StreamAlerts(grpc.BidiStreamingServer[AlertMessage, AlertMessage]) error
type UnsafeGreeterServer ¶
type UnsafeGreeterServer interface {
// contains filtered or unexported methods
}
UnsafeGreeterServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to GreeterServer will result in compilation errors.